Pootle
======

.. image:: https://img.shields.io/travis/translate/pootle.svg?style=flat-square
    :alt: Build Status
    :target: https://travis-ci.org/translate/pootle

`Pootle <http://pootle.translatehouse.org/>`_ is an online translation and
localization tool.  It works to lower the barrier of entry, providing tools to
enable teams to work towards higher quality while welcoming newcomers.


Pootle is a Server
------------------

Pootle is written in Python using the Django framework and therefore can be
installed on any web server that supports serving WSGI applications.

A number of translation projects for a number of languages can be hosted on
Pootle.  Teams can manage their files, permissions, projects, and translate
on-line.  Files can be downloaded for offline translation.

Installation can be done via pip::

  pip install Pootle

But don't forget to read the `installation guide
<http://docs.translatehouse.org/projects/pootle/en/latest/server/installation.html>`_
for the important details.


Resources
---------

- `Pootle Website <http://pootle.translatehouse.org/>`_
- `Documentation <http://docs.translatehouse.org/projects/pootle/>`_
- `Translations <http://pootle.locamotion.org/projects/pootle/>`_
- `Bug Tracker <https://github.com/translate/pootle/issues>`_
- `Mailing List
  <https://lists.sourceforge.net/lists/listinfo/translate-pootle>`_
- Support: `#pootle on chat.freenode.net <irc://chat.freenode.net/#pootle>`_
- Development: `#pootle-dev on chat.freenode.net <irc://chat.freenode.net/#pootle-dev>`_

Copying
-------

Pootle is released under the General Public License, version 3 or later. See
the file LICENSE for details.
